@@ -85,3 +85,10 @@ class UnknownFile(KeyError, NotFoundError):
     """
 
     pass
+
+
+class UnsupportMethod(Exception):
+    """
+    This Error will be raised when program calls methods or parameters that are currently unsupported
+    """
+    pass
